@@ -26,4 +26,5 @@
 
 # created 2012-08-28 by J. Fox
 
-if (getRversion() >= '2.15.1') globalVariables(c('top', 'buttonsFrame', 'slider.env'))
+if (getRversion() >= '2.15.1') globalVariables(c('top', 'buttonsFrame', 'slider.env','dataCovid',
+                                                 'dataCovidFin','countries.mort','popRegionsFin'))
